@@ -1,12 +1,16 @@
 """Fake mixer for use in tests.
 
-**Dependencies:**
+Dependencies
+============
 
-- None
+None
 
-**Settings:**
 
-- Set :attr:`mopidy.settings.MIXER` to ``fakemixer`` to use this mixer.
+Configuration
+=============
+
+Set the :confval:`audio/mixer:` config value to ``fakemixer`` to use this
+mixer.
 """
 
 from __future__ import unicode_literals
