@@ -5,7 +5,6 @@ import logging
 import os
 import shutil
 
-from mopidy import settings
 from mopidy.backends import base, listener
 from mopidy.models import Playlist
 from mopidy.utils import formatting, path
@@ -19,7 +18,8 @@ logger = logging.getLogger('mopidy.backends.local')
 class LocalPlaylistsProvider(base.BasePlaylistsProvider):
     def __init__(self, *args, **kwargs):
         super(LocalPlaylistsProvider, self).__init__(*args, **kwargs)
-        self._path = settings.LOCAL_PLAYLIST_PATH
+        self._media_dir = self.backend.config['local']['media_dir']
+        self._playlists_dir = self.backend.config['local']['playlists_dir']
         self.refresh()
 
     def create(self, name):
@@ -42,16 +42,14 @@ class LocalPlaylistsProvider(base.BasePlaylistsProvider):
                 return playlist
 
     def refresh(self):
-        logger.info('Loading playlists from %s', self._path)
-
         playlists = []
 
-        for m3u in glob.glob(os.path.join(self._path, '*.m3u')):
+        for m3u in glob.glob(os.path.join(self._playlists_dir, '*.m3u')):
             uri = path.path_to_uri(m3u)
             name = os.path.splitext(os.path.basename(m3u))[0]
 
             tracks = []
-            for track_uri in parse_m3u(m3u, settings.LOCAL_MUSIC_PATH):
+            for track_uri in parse_m3u(m3u, self._media_dir):
                 try:
                     # TODO We must use core.library.lookup() to support tracks
                     # from other backends
@@ -65,6 +63,10 @@ class LocalPlaylistsProvider(base.BasePlaylistsProvider):
         self.playlists = playlists
         listener.BackendListener.send('playlists_loaded')
 
+        logger.info(
+            'Loaded %d local playlists from %s',
+            len(playlists), self._playlists_dir)
+
     def save(self, playlist):
         assert playlist.uri, 'Cannot save playlist without URI'
 
@@ -86,13 +88,13 @@ class LocalPlaylistsProvider(base.BasePlaylistsProvider):
 
     def _get_m3u_path(self, name):
         name = formatting.slugify(name)
-        file_path = os.path.join(self._path, name + '.m3u')
-        path.check_file_path_is_inside_base_dir(file_path, self._path)
+        file_path = os.path.join(self._playlists_dir, name + '.m3u')
+        path.check_file_path_is_inside_base_dir(file_path, self._playlists_dir)
         return file_path
 
     def _save_m3u(self, playlist):
         file_path = path.uri_to_path(playlist.uri)
-        path.check_file_path_is_inside_base_dir(file_path, self._path)
+        path.check_file_path_is_inside_base_dir(file_path, self._playlists_dir)
         with open(file_path, 'w') as file_handle:
             for track in playlist.tracks:
                 if track.uri.startswith('file://'):
@@ -103,16 +105,18 @@ class LocalPlaylistsProvider(base.BasePlaylistsProvider):
 
     def _delete_m3u(self, uri):
         file_path = path.uri_to_path(uri)
-        path.check_file_path_is_inside_base_dir(file_path, self._path)
+        path.check_file_path_is_inside_base_dir(file_path, self._playlists_dir)
         if os.path.exists(file_path):
             os.remove(file_path)
 
     def _rename_m3u(self, playlist):
         src_file_path = path.uri_to_path(playlist.uri)
-        path.check_file_path_is_inside_base_dir(src_file_path, self._path)
+        path.check_file_path_is_inside_base_dir(
+            src_file_path, self._playlists_dir)
 
         dst_file_path = self._get_m3u_path(playlist.name)
-        path.check_file_path_is_inside_base_dir(dst_file_path, self._path)
+        path.check_file_path_is_inside_base_dir(
+            dst_file_path, self._playlists_dir)
 
         shutil.move(src_file_path, dst_file_path)
 
