@@ -1,32 +1,37 @@
 from __future__ import unicode_literals
 
 import logging
+import os
 
 import pykka
 
-from mopidy import settings
 from mopidy.core import CoreListener
 from mopidy.frontends.mpris import objects
 
 logger = logging.getLogger('mopidy.frontends.mpris')
 
 try:
-    import indicate
-except ImportError as import_error:
-    indicate = None  # noqa
-    logger.debug('Startup notification will not be sent (%s)', import_error)
+    indicate = None
+    if 'DISPLAY' in os.environ:
+        import indicate
+except ImportError:
+    pass
+
+if indicate is None:
+    logger.debug('Startup notification will not be sent')
 
 
 class MprisFrontend(pykka.ThreadingActor, CoreListener):
-    def __init__(self, core):
+    def __init__(self, config, core):
         super(MprisFrontend, self).__init__()
+        self.config = config
         self.core = core
         self.indicate_server = None
         self.mpris_object = None
 
     def on_start(self):
         try:
-            self.mpris_object = objects.MprisObject(self.core)
+            self.mpris_object = objects.MprisObject(self.config, self.core)
             self._send_startup_notification()
         except Exception as e:
             logger.error('MPRIS frontend setup failed (%s)', e)
@@ -53,7 +58,8 @@ class MprisFrontend(pykka.ThreadingActor, CoreListener):
         logger.debug('Sending startup notification...')
         self.indicate_server = indicate.Server()
         self.indicate_server.set_type('music.mopidy')
-        self.indicate_server.set_desktop_file(settings.DESKTOP_FILE)
+        self.indicate_server.set_desktop_file(
+            self.config['mpris']['desktop_file'])
         self.indicate_server.show()
         logger.debug('Startup notification sent')
 
