@@ -1,7 +1,6 @@
 from __future__ import unicode_literals
 
-from mopidy import settings
-from mopidy.backends.local import LocalBackend
+from mopidy.backends.local import actor
 from mopidy.core import PlaybackState
 from mopidy.models import Track
 from mopidy.utils.path import path_to_uri
@@ -12,19 +11,17 @@ from tests.backends.local import generate_song
 
 
 class LocalPlaybackControllerTest(PlaybackControllerTest, unittest.TestCase):
-    backend_class = LocalBackend
+    backend_class = actor.LocalBackend
+    config = {
+        'local': {
+            'media_dir': path_to_data_dir(''),
+            'playlists_dir': b'',
+            'tag_cache_file': path_to_data_dir('empty_tag_cache'),
+        }
+    }
     tracks = [
         Track(uri=generate_song(i), length=4464) for i in range(1, 4)]
 
-    def setUp(self):
-        settings.BACKENDS = ('mopidy.backends.local.LocalBackend',)
-        settings.LOCAL_TAG_CACHE_FILE = path_to_data_dir('empty_tag_cache')
-        super(LocalPlaybackControllerTest, self).setUp()
-
-    def tearDown(self):
-        super(LocalPlaybackControllerTest, self).tearDown()
-        settings.runtime.clear()
-
     def add_track(self, path):
         uri = path_to_uri(path_to_data_dir(path))
         track = Track(uri=uri, length=4464)
